<?php

namespace IQBall\App\Controller;

use IQBall\App\Session\MutableSessionHandle;
use IQBall\App\Session\SessionHandle;
use IQBall\App\ViewHttpResponse;
use IQBall\Core\Http\HttpResponse;
use IQBall\Core\Model\TacticModel;
use IQBall\Core\Model\TeamModel;

class UserController {
    private TacticModel $tactics;
    private ?TeamModel $teams;


    /**
     * @param TacticModel $tactics
     */
    public function __construct(TacticModel $tactics, ?TeamModel $teams = NULL) {
        $this->tactics = $tactics;
        $this->teams = $teams;
    }

    /**
     * @param SessionHandle $session
     * @return ViewHttpResponse the home page view
     */
    public function home(SessionHandle $session): ViewHttpResponse {
        $limitNbTactics = 5;
        $lastTactics = $this->tactics->getLast($limitNbTactics, $session->getAccount()->getId());
        $allTactics = $this->tactics->getAll($session->getAccount()->getId());
        
        //TODO
        if ($this->teams != NULL) {
            $teams = $this->teams->getAll($session->getAccount()->getId());
        }
        else {
            $teams = [];
        }

        return ViewHttpResponse::react("views/Home.tsx", [
            "lastTactics" => $lastTactics,
            "allTactics" => $allTactics,
            "teams" => $teams
        ]);
        // return ViewHttpResponse::react("views/Home.tsx", []);
    }

    public function homeTwig(SessionHandle $session): ViewHttpResponse {
        return ViewHttpResponse::twig("home.twig", []);
    }

    /**
     * @return ViewHttpResponse account settings page
     */
    public function settings(SessionHandle $session): ViewHttpResponse {
        return ViewHttpResponse::twig("account_settings.twig", []);
    }

    public function disconnect(MutableSessionHandle $session): HttpResponse {
        $session->destroy();
        return HttpResponse::redirect("/");
    }

}
