<?php

namespace IQBall\Core\Data;

use InvalidArgumentException;

/**
 * Enumeration class workaround
 * As there is no enumerations in php 7.4, this class
 * encapsulates an integer value and use it as a variant discriminant
 */
final class CourtType {
    private const COURT_PLAIN = 0;
    private const COURT_HALF = 1;
    private int $value;

    private function __construct(int $val) {
        if ($val < self::COURT_PLAIN || $val > self::COURT_HALF) {
            throw new InvalidArgumentException("Valeur du rôle invalide");
        }
        $this->value = $val;
    }

    public static function plain(): CourtType {
        return new CourtType(CourtType::COURT_PLAIN);
    }

    public static function half(): CourtType {
        return new CourtType(CourtType::COURT_HALF);
    }

    public function name(): string {
        switch ($this->value) {
            case self::COURT_HALF:
                return "HALF";
            case self::COURT_PLAIN:
                return "PLAIN";
        }
        die("unreachable");
    }

    public static function fromName(string $name): ?CourtType {
        switch ($name) {
            case "HALF":
                return CourtType::half();
            case "PLAIN":
                return CourtType::plain();
            default:
                return null;
        }
    }

    public function isPlain(): bool {
        return ($this->value == self::COURT_PLAIN);
    }

    public function isHalf(): bool {
        return ($this->value == self::COURT_HALF);
    }

}
