<?php

namespace IQBall\Core\Gateway;

use IQBall\Core\Connection;
use IQBall\Core\Data\Account;
use PDO;

class AccountGateway {
    private Connection $con;

    /**
     * @param Connection $con
     */
    public function __construct(Connection $con) {
        $this->con = $con;
    }


    public function insertAccount(string $name, string $email, string $token, string $hash): int {
        $this->con->exec("INSERT INTO Account(username, hash, email, token) VALUES (:username,:hash,:email,:token)", [
            ':username' => [$name, PDO::PARAM_STR],
            ':hash' => [$hash, PDO::PARAM_STR],
            ':email' => [$email, PDO::PARAM_STR],
            ':token' => [$token, PDO::PARAM_STR],
        ]);
        return intval($this->con->lastInsertId());
    }

    /**
     * @param string $email
     * @return array<string, mixed>|null
     */
    private function getRowsFromMail(string $email): ?array {
        return $this->con->fetch("SELECT * FROM Account WHERE email = :email", [':email' => [$email, PDO::PARAM_STR]])[0] ?? null;
    }

    /**
     * @param string $email
     * @return string|null the hashed user's password, or null if the given mail does not exist
     */
    public function getHash(string $email): ?string {
        $results = $this->getRowsFromMail($email);
        if ($results == null) {
            return null;
        }
        return $results['hash'];
    }

    /**
     * @param string $email
     * @return bool true if the given email exists in the database
     */
    public function exists(string $email): bool {
        return $this->getRowsFromMail($email) != null;
    }

    /**
     * @param string $email
     * @return Account|null
     */
    public function getAccountFromMail(string $email): ?Account {
        $acc = $this->getRowsFromMail($email);
        if (empty($acc)) {
            return null;
        }

        return new Account($email, $acc["username"], $acc["token"], $acc["id"]);
    }

    /**
     * @param string $token get an account from given token
     * @return Account|null
     */
    public function getAccountFromToken(string $token): ?Account {
        $acc = $this->con->fetch("SELECT * FROM Account WHERE token = :token", [':token' => [$token, PDO::PARAM_STR]])[0] ?? null;
        if (empty($acc)) {
            return null;
        }

        return new Account($acc["email"], $acc["username"], $acc["token"], $acc["id"]);
    }


}
